@@ -67,6 +67,10 @@ class BaseAPI:
         self.base_url = base_url
         self.timeout = timeout
         self._set_transport_class(transport_class=transport_class or RequestsTransport)
+        self.kwargs = kwargs
+
+    def _render_response(self, response, endpoint):
+        ResponseFactory(response, endpoint)
 
     def _set_transport_class(self, transport_class):
         headers = self.get_default_headers()
@@ -126,6 +130,8 @@ class BaseAPI:
         Args:
             endpoint (str): URL for the API endpoint.
             data (dict, list of tuples): Data to send in the body of the request.
+            files (dict, list of tuples): Files to send in the body of the request.
+            content_type (str): Request Content Type. E.g: 'application/json', 'form-data'
 
         Returns:
             dict: Data retrieved for specified endpoint.
@@ -133,13 +139,15 @@ class BaseAPI:
         if content_type == 'application/json' or not files:
             data = json.dumps(data, default=json_converter)
         response = self.make_request('POST', endpoint, data=data, files=files, content_type=content_type)
-        return ResponseFactory(response, endpoint)
+        return self._render_response(response, endpoint)
 
-    def update(self, endpoint, data={}, partial=False, content_type='application/json'):
+    def update(self, endpoint, data={}, files=None, partial=False, content_type='application/json'):
         """Do a update (PUT/PATCH) without need to pass all arguments to make a request
         Args:
             endpoint (str): URL for the API endpoint.
             data (dict, list of tuples): Data to send in the body of the request.
+            files (dict, list of tuples): Files to send in the body of the request.
+            content_type (str): Request Content Type. E.g: 'application/json', 'form-data'
             partial (bool): To specify whether the update will change everything
                             or just a few attributes. Default is False
 
@@ -149,8 +157,13 @@ class BaseAPI:
         method = 'PATCH' if partial else 'PUT'
         if content_type == 'application/json':
             data = json.dumps(data, default=json_converter)
+
+        if files:
+            response = self.make_request(method, endpoint, data=data, files=files, content_type=content_type)
+            return self._render_response(response, endpoint)
+
         response = self.make_request(method, endpoint, data=data, content_type=content_type)
-        return ResponseFactory(response, endpoint)
+        return self._render_response(response, endpoint)
 
     def search(self, endpoint, **kwargs):
         """Do a GET to make a search without need
@@ -165,7 +178,7 @@ class BaseAPI:
         """
         params = kwargs.pop('params', {})
         response = self.make_request('GET', endpoint, params=params)
-        return ResponseFactory(response, endpoint)
+        return self._render_response(response, endpoint)
 
     def delete(self, endpoint):
         """Do a DELETE request to remove a resource
@@ -176,7 +189,7 @@ class BaseAPI:
             dict: Empty
         """
         response = self.make_request('DELETE', endpoint)
-        return ResponseFactory(response, endpoint)
+        return self._render_response(response, endpoint)
 
 
 class BaseEndpoint:
@@ -255,6 +268,8 @@ class BaseEndpoint:
 
         Args:
             data (dict, list of tuples): Data to send in the body of the request.
+            files (dict, list of tuples): Files to send in the body of the request.
+            content_type (str): Request Content Type. E.g: 'application/json', 'form-data'
 
         Returns:
             dict: Data retrieved for specified endpoint.
@@ -266,14 +281,16 @@ class BaseEndpoint:
 
         """
         endpoint = self.get_endpoint(*args, **kwargs)
-        return self._api.create(endpoint, data, files=files, content_type=content_type)
+        return self._api.create(endpoint, data=data, files=files, content_type=content_type)
 
-    def update(self, object_id, data={}, partial=False, content_type='application/json', *args, **kwargs):
+    def update(self, object_id, data={}, files=None, partial=False, content_type='application/json', *args, **kwargs):
         """Update a single Object.
 
         Args:
             object_id (str): Object ID.
             data (dict, list of tuples): Data to send in the body of the request.
+            files (dict, list of tuples): Files to send in the body of the request.
+            content_type (str): Request Content Type. E.g: 'application/json', 'form-data'
             partial (bool): To specify whether the update will change everything
                             or just a few attributes. Default is False
 
@@ -287,7 +304,7 @@ class BaseEndpoint:
 
         """
         endpoint = self.get_endpoint(object_id, detail=True, *args, **kwargs)
-        return self._api.update(endpoint, data, partial, content_type=content_type)
+        return self._api.update(endpoint, data=data, files=files, partial=partial, content_type=content_type)
 
     def delete(self, object_id, *args, **kwargs):
         """Delete a single resource
